@@ -907,14 +907,24 @@ class WordToken(models.Model):
             p.get_formants(self.getDialogPath(),beg,end,nformants,ceiling)
             return out
         else:
-            outline['F1'] = self.getStrF1()
-            outline['F2'] = self.getStrF2()
-            if form['measure'] == 'D':
+            F1 = self.getStrF1()
+            F2 = self.getStrF2()
+            if F1 is None:
+                outline['F1'] = 'NA'
+            else:
+                outline['F1'] = F1
+            if F2 is None:
+                outline['F2'] = 'NA'
+            else:
+                outline['F2'] = F2
+            if form['measure'] == 'D' and 'NA' not in [outline['F1'],outline['F2']]:
                 if form['DispersionFromAH']:
                     center = self.Dialog.Speaker.getAHCenter()
                 else:
                     center = self.Dialog.Speaker.getCenter()
                 outline['Dispersion'] = math.sqrt(math.pow(outline['F1']-center[0],2)+math.pow(outline['F2']-center[1],2))
+            elif form['measure'] == 'D':
+                outline['Dispersion'] = 'NA'
         return [outline]
 
 #class SynSemCase(models.Model):
